import jwt, { JwtPayload } from "jsonwebtoken";
import AuthService from "../services/AuthService";
import { Request, Response, NextFunction } from "express";
import logger from "../logger";

const authTokenSecret = process.env.JWTSECRET || "badsecret";

class AuthControler {
  async login(req: Request, res: Response) {
    // Read app and secret from request body
    const { app, secret } = req.body;

    // Filter app from the apps by app and secret
    const authenticated = await AuthService.find(app, secret);

    if (authenticated) {
      logger.info("Authenticated app", authenticated.app);
      // Generate an access token
      const token = jwt.sign({ app: authenticated.app }, authTokenSecret, {
        expiresIn: "1h",
      });

      res.json({ token });
    } else {
      logger.warn("Authentication attempt for", app);
      res.status(403).send("Credentials incorrect");
    }
  }

  authorize(req: Request, res: Response, next: NextFunction) {
    const authHeader = req.headers.authorization;
    if (authHeader) {
      const token = authHeader.split(" ")[1];

      jwt.verify(token, authTokenSecret, (err, app) => {
        if (err) {
          return res.status(403).json("Invalid token provided");
        }
        logger.info(
          `Authorization for ${req.method} ${req.url} provided to app ${
            (app as JwtPayload).app
          } `
        );
        next();
      });
    } else {
      res.status(401).json("No Authorization header provided");
    }
  }
}

export default new AuthControler();
