import mongoose, { Document } from "mongoose";

export interface Image extends Document {
  url: string;
  status: "consumed" | "unavailable" | "available";
  tags?: string[];
}

const ImageSchema = new mongoose.Schema(
  {
    url: {
      type: String,
      required: true,
      index: true,
      unique: true,
    },
    status: {
      type: String,
      enum: {
        values: ["consumed", "unavailable", "available"],
      },
      required: true,
      index: true,
    },
    tags: {
      type: [String],
    },
  },
  { collection: "images" }
);

export default mongoose.model<Image>("images", ImageSchema);
