import imageModel, { Image } from "../models/ImageModel";

class ImageService {
  async replaceOne(id: string, newimage: Image) {
    const result = await imageModel.updateOne({ _id: id }, newimage);
    return result;
  }
  async findById(id: string) {
    const image = await imageModel.findOne({ _id: id });
    return image;
  }

  async findAll(limit?: number, status?: Image["status"]): Promise<Image[]> {
    const typeError = TypeError(
      "if present, `limit` must be a non-negative integer"
    );
    const filter = status !== undefined ? { status } : {};
    let query = imageModel.find(filter);
    if (limit !== undefined) {
      if (Number.isInteger(limit)) {
        if (limit > 0) query = query.limit(limit);
        else if (limit < 0) throw typeError;
      } else {
        throw typeError;
      }
    }
    const allImages = await query;
    return allImages;
  }

  async add(image: Image): Promise<Image> {
    const newImage = await imageModel.create(image);
    return newImage;
  }
}

export default new ImageService();
